// Toggle classes on Dropdowns/Modals/Menus/Toasts
function toggleClasses() {
    var targetSelectors = $(this).data('target').split(','); // Split multiple targets by comma
    var $targets = $(); // Initialize an empty jQuery object

    // Iterate over each target selector
    targetSelectors.forEach(function (targetSelector) {
        var $target;

        targetSelector = targetSelector.trim(); // Trim whitespace from selector

        if (targetSelector === "self") {
            $target = $(this);
        } else if (targetSelector === "parent") {
            $target = $(this).parent();
        } else if (targetSelector === "grandparent") {
            $target = $(this).parent().parent();
        } else {
            $target = $(this).siblings(targetSelector);
            if ($target.length === 0) {
                // If no sibling found, use the global selector
                $target = $(targetSelector);
            }
        }

        // Add found targets to the main jQuery object
        $targets = $targets.add($target);
    }, this); // Ensure 'this' refers to the clicked element

    if ($targets.length > 0) {
        $targets.toggleClass('active');
    }

    // Check for data-overlay attribute
    if ($(this).data('overlay') === true) {
        $('.overlay').toggleClass('active');
    }

    // Check for data-fixed attribute
    if ($(this).data('fixed') === true) {
        $('body').toggleClass('fixed');
        $('html').toggleClass('fixed');
    }

    // Check for data-dropdown attribute
    if ($(this).data('dropdown') === true && $(window).width() >= 640) {
        $('body').removeClass('fixed');
        $('.overlay').removeClass('active');
    }


    // Check for data-modal attribute
    if ($(this).data('modal') === true) {
        if (!$('.overlay').hasClass('active')) {
            $('.overlay').addClass('active');
        }
        if (!$('body').hasClass('fixed')) {
            $('body').addClass('fixed');
            $('html').addClass('fixed');
        }
    }

    // Setting of source means we set the content of the target with material from the source.  This is useful for the modal designs where we need the content of the modal
    // to be something else on the page.
    var sourceSet = $(this).data('setsource');
    if (sourceSet) {
        if (sourceSet == true) {
            var sourceTarget = $(this).data('setsourcetarget');

            $(sourceTarget).empty();

            var sourceMaterial = $(this).data('source');

            $(sourceTarget).append($(sourceMaterial).html());

            var removeClass = $(this).data('remove');

            if (removeClass) {
                $(sourceTarget).find(removeClass).remove();
            }
        }
    }

    // Handle toast-related data attributes
    var toastTarget = $(this).data('toast-target');
    if (toastTarget) {
        var $toast = $(toastTarget);
        //This turns the toast to visible.
        $toast.addClass('active');

        // Always apply the toast class
        var toastClass = $(this).data('toast-class');
        if (toastClass) {
            $toast.addClass(toastClass);
        }

        //determine what the status class is for the toast.  This determines its toggle status.  If this class is present, we are "active", if not present, "not active".
        var toggleClass = $(this).data("statusclass");
        //You can specify if you want THIS click event to toggle the toggle status or if something else is going to handle that for you.
        var toggleOnClick = $(this).data("toggleonclick");

        if (toggleOnClick) {
            $(this).toggleClass(toggleClass);
        }


        // Update toast title and message based on new data attributes if .active is present
        if ($(this).hasClass(toggleClass)) {
            var newTitle = $(this).data('active-toast-title');
            var newMessage = $(this).data('active-toast-message');

            $toast.addClass('')

            if (newTitle !== undefined) {
                $toast.find('h3').html(newTitle);
            }

            if (newMessage !== undefined) {
                $toast.find('p').html(newMessage);
            }
        } else {
            // Handle default toast title and message if needed
            if ($(this).data('toast-title')) {
                $toast.find('h3').html($(this).data('toast-title'));
            }

            if ($(this).data('toast-message')) {
                $toast.find('p').html($(this).data('toast-message'));
            }
        }

        //Clear any previous timer so the toast stays on the page for 5 seconds since last action
        clearTimeout(toastTimer);

        // Set a timeout to hide the toast after 5 seconds.  This will remove active
        toastTimer = setTimeout(function () {
            $toast.removeClass('active');
        }, 5000); // 5000 milliseconds = 5 seconds
    }
    // Check for data-disable attribute
    if ($(this).data('disable') === true) {
        $(this).prop('disabled', true); // Disable the button
        return; // Exit the function early if the button is disabled
    }
}


function Toggles_BindToggles() {
    $('.toggle-button').each(function () {
        if (!$(this).hasClass('toggle-bound')) {
            $(this).on('click', toggleClasses);
            $(this).addClass('toggle-bound');
        }
    });
}



var toastTimer;


//This called from page manager as things load.  Keeps binding things that aren't bound.
function SiteWideBinding() {
    Toggles_BindToggles();
}




$(document).ready(function () {
    Toggles_BindToggles(); //toggle binding on page load.

    // Function to close all modals and overlay
    function closeModals() {
        $('.dropdown-container.active, .modal.active, aside.filter.active').removeClass('active');
        $('.overlay.active').removeClass('active');
        $('body').removeClass('fixed');
        $('html').removeClass('fixed');
    }

// Click event to close active element if clicked outside
$(document).mouseup(function (e) {
var activeElement = $('.links-section.active, .dropdown-container.active, .modal.active, aside.filter.active, .media-options-container.active');
    
    // Check if the click target is outside the active elements
    if (!activeElement.is(e.target) && activeElement.has(e.target).length === 0) {
        activeElement.removeClass('active');
        $('.overlay').removeClass('active'); // Optional: remove overlay if applicable
        $('body').removeClass('fixed');
        $('html').removeClass('fixed');
    }
});


    // Keydown event to close modal on Escape key press
    $(document).keydown(function (e) {
        if (e.key === "Escape") {
            closeModals();
        }
    });

   // Swipe down event to close modal on touch devices
    if ($(window).width() < 640) {
        var startY;

        $(document).on('touchstart', '.dropdown-container.active, .modal.active', function (e) {
            startY = e.originalEvent.touches[0].clientY;
        });

        $(document).on('touchmove', '.dropdown-container.active, .modal.active', function (e) {
            var moveY = e.originalEvent.touches[0].clientY;
            if (moveY > startY + 50) { // swipe down threshold
                closeModals();
            }
        });
    }
});




/*
 $(document).ready(function () {
    // Function to toggle the disabled attribute and title attribute
    function toggleCreateButton() {
        var $createButton = $('.create-new-list-button');
        if ($('#newListTitle').val().trim() === '') {
            $createButton.attr('disabled', 'disabled');
            $createButton.attr('title', 'Please enter a list name'); // Add title attribute
        } else {
            $createButton.removeAttr('disabled');
            $createButton.removeAttr('title'); // Remove title attribute
        }
    }

    // Initial check when the page loads
    toggleCreateButton();

    // Event listener for input changes
    $('#newListTitle').on('input', function () {
        toggleCreateButton();
    });
}); 
*/

$(document).ready(function () {
    $('.create-new-list-button').click(function () {
        var newListTitle = $('#newListTitle').val().trim();

        if (newListTitle !== '') {
            // Clear input field
            $('#newListTitle').val('');

            // Remove .active class from .dropdown-new-list-container
            $('.dropdown-new-list-container').removeClass('active');

            // Generate a unique ID for the new checkbox
            var newCheckboxId = 'checkbox' + ($('.checkbox-container').length + 1);

            // Create new checkbox container HTML
            var newCheckboxHTML = `
                <div class="checkbox-container">
                    <input type="checkbox" id="${newCheckboxId}" checked>
                    <label for="${newCheckboxId}">
                        <span class="checkbox-label">${newListTitle}</span>
                        <span class="custom-checkbox">
                            <i class="fa-solid fa-check"></i>
                        </span>
                    </label>
                </div>`;

            // Insert new checkbox container above the first one
            $('.checkbox-container').first().before(newCheckboxHTML);
        }
    });
});


// Function to adjust the dimensions of the image containers
function adjustImageContainers() {
    if ($(window).width() <= 1279) {
        $('.img-container').each(function () {
            var $imgContainer = $(this);
            var width = $imgContainer.width();
            var height = width * 0.5625;

            $imgContainer.css('height', height);

            if ($imgContainer.parent('.author').length) {
                $imgContainer.css('width', height);
            }
        });
    } else {
        // Reset the styles if the width is above 1279px
        $('.img-container').css({
            'height': '',
            'width': ''
        });
    }
}

// Debounce function to limit the rate at which a function can fire
function debounce(func, wait) {
    var timeout;
    return function () {
        clearTimeout(timeout);
        timeout = setTimeout(func, wait);
    };
}

// Ensure Card Image is 16:9 when document is ready
$(document).ready(function () {
    adjustImageContainers();

    // Adjust dimensions on window resize with debouncing
    $(window).resize(debounce(adjustImageContainers, 100));
});


//Get year
$(document).ready(function () {
    var currentYear = new Date().getFullYear();
    $('#current-year').text(currentYear);
});

//Remove vote
$(document).ready(function () {
    $('.post-vote.toggle-button').on('click', function (event) {
        event.preventDefault(); // Prevent default action of the link
        $('.vote-button').prop('disabled', function (i, v) {
            return !v;
        });
    });
});



// Randomly coloured avatars
$(document).ready(function () {
    var classes = ['dark-blue', 'light-blue', 'purple', 'red', 'peach', 'orange', 'yellow', 'green', 'aqua', 'mint'];
    var prevClass = null;

    $('.author, .media').each(function () {
        var availableClasses = classes.slice(); // Create a copy of the classes array

        // Remove the previous class from the available classes to ensure no repetition
        if (prevClass) {
            var index = availableClasses.indexOf(prevClass);
            if (index > -1) {
                availableClasses.splice(index, 1);
            }
        }

        // Randomly select a class from the available classes
        var randomClass = availableClasses[Math.floor(Math.random() * availableClasses.length)];

        // Assign the class to the .author-avatar element
        $(this).find('.author-avatar').addClass(randomClass);

        // Update the previous class to the current class
        prevClass = randomClass;
    });
});

$(document).ready(function() {
  function handleSwipeDown() {
    // Check if the window width is less than 640px
    if ($(window).width() < 640) {
      // Bind swipe event on the collapsible-content menu
      $('.collapsible-content.media-options-menu').on('swipedown', function() {
        // Remove the 'active' class from the parent element
        $(this).parent().removeClass('active');
      });
    }
  }

  // Run the function on initial page load
  handleSwipeDown();

  // Re-run the function when the window is resized
  $(window).resize(function() {
    handleSwipeDown();
  });
});